@@ -5,7 +5,7 @@ use warnings;
 use Moo::Role;
 use namespace::autoclean;
 
-our $VERSION = '1.000';
+our $VERSION = '1.014';
 
 with qw(
     Locale::TextDomain::OO::Plugin::Expand::Maketext
@@ -13,10 +13,12 @@ with qw(
 
 {
     no warnings qw(redefine); ## no critic (NoWarnings)
-    *loc    = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::maketext;
-    *loc_p  = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::maketext_p;
-    *Nloc   = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::Nmaketext;
-    *Nloc_p = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::Nmaketext_p;
+    *loc     = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::maketext;
+    *loc_m   = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::maketext;
+    *loc_mp  = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::maketext_p;
+    *Nloc    = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::Nmaketext;
+    *Nloc_m  = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::Nmaketext;
+    *Nloc_mp = \&Locale::TextDomain::OO::Plugin::Expand::Maketext::Nmaketext_p;
 }
 
 1;
@@ -27,13 +29,13 @@ __END__
 
 Locale::TextDomain::OO::Plugin::Expand::Maketext::Loc - Alternative maketext methods
 
-$Id: Loc.pm 439 2013-12-19 20:42:34Z steffenw $
+$Id: Loc.pm 545 2014-10-30 13:23:00Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Plugin/Expand/Maketext/Loc.pm $
 
 =head1 VERSION
 
-1.000
+1.014
 
 =head1 DESCRIPTION
 
@@ -51,10 +53,11 @@ This module provides alternative maketext methods.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 methods loc, loc_p, Nloc, Nloc_p
+=head2 methods loc, loc_m, loc_mp, Nloc, Nloc_m, Nloc_mp
 
 This methods are aliases to method
-maketext, maketext_p, Nmaketext and Nmaketext_p.
+maketext, maketext, maketext_p,
+Nmaketext, Nmaketext and Nmaketext_p.
 
 =head1 EXAMPLE
 
@@ -95,7 +98,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2013,
+Copyright (c) 2013 - 2014,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
